from setuptools import setup, find_packages

setup(
    name="almost_p2p_chat",
    version="0.0.2",
    description="library for p2p_chat",
    author="Eugene-Lasevich",
    author_email="lasevich009@gmail.com",
    classifiers=[
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3.11",
        "Operating System :: OS Independent"
    ],
    packages=["almost_p2p_chat"],
    include_package_data=True
)